Module indexes_api

Module indexes_api 

Enums

CreateIndexError
struct for typed errors of method create_index
DeleteIndexError
struct for typed errors of method delete_index
ListIndexesCollectionError
struct for typed errors of method list_indexes_collection
ListIndexesError
struct for typed errors of method list_indexes

Functions

create_index
Create a sorted or BM25 full-text index on a cached table.
delete_index
Delete a specific index from a cached table.
list_indexes
List all indexes created on a cached table.
list_indexes_collection
List all indexes in the database identified by the required X-Database-Id header, paginated. Optional filters narrow by connection, schema, table, or index type.