Enums
- Create
Index Error - struct for typed errors of method
create_index - Delete
Index Error - struct for typed errors of method
delete_index - List
Indexes Collection Error - struct for typed errors of method
list_indexes_collection - List
Indexes Error - struct for typed errors of method
list_indexes
Functions
- create_
index - Create a sorted or BM25 full-text index on a cached table.
- delete_
index - Delete a specific index from a cached table.
- list_
indexes - List all indexes created on a cached table.
- list_
indexes_ collection - List all indexes in the database identified by the required X-Database-Id header, paginated. Optional filters narrow by connection, schema, table, or index type.